@@ -12,6 +12,7 @@
 
 #include "libkita/favoritethreads.h"
 #include "libkita/board.h"
+#include "libkita/kita_misc.h"
 #include "kitacacheinfo.h"
 
 #include <qmap.h>
@@ -70,13 +71,12 @@ void FavoriteListView::update()
   QDictIterator<Kita::Thread> it( threads );
   for(; it.current(); ++it) {
     const Kita::Thread* thread = it.current();
-    const Kita::Board* board = thread->getBoard();
 
     int readNum = cache->readNum( thread->datURL() );
-    int resNum = cache->resNum( thread->datURL() );
+    int resNum = cache->resNum( thread->datURL() );  // TODO unused variables.
 
     new KListViewItem( this,
-                       board->name(),
+                       thread->boardName(),
                        "",
                        thread->name(),
                        "",
@@ -129,10 +129,11 @@ void FavoriteListView::slotContextMenuRequested( QListViewItem* item, const QPoi
   KURL datURL = KURL( item->text(Row_DatURL) );
 
   kdDebug() << "datURL = " << datURL.url() << endl;
-  Kita::Board board = Kita::Board( KURL( datURL, ".." ) );
-  kdDebug() << "board.url = " << board.url().url() << endl;
-  Kita::Thread thread( board, datURL );
-  kdDebug() << "thread.url = %s" << thread.url().url() << endl;
+  Kita::Board board = Kita::Board( Kita::datToBoard( datURL.url() ) );
+  kdDebug() << "board.url = " << board.url() << endl;
+  Kita::Board::setName( Kita::datToBoard( datURL.url() ), board.name() );
+  Kita::Thread thread( datURL );
+  kdDebug() << "thread.url = %s" << thread.url() << endl;
   thread.setName( item->text( Row_Subject ) );
   thread.setResNum( item->text( Row_Read ).toInt() );
 
@@ -146,7 +147,7 @@ void FavoriteListView::slotContextMenuRequested( QListViewItem* item, const QPoi
     emit signalShowThreadWithNewTab( thread );
     break;
   case 2:
-    clipboard->setText( thread.name() + "\n" + thread.url().url() );
+    clipboard->setText( thread.name() + "\n" + thread.url() );
     break;
   default:
     break;
