@@ -157,7 +157,7 @@ void KitaMainWindow::load(const KURL& url)
 void KitaMainWindow::setupActions()
 {
   KStdAction::openNew(this, SLOT(fileNew()), actionCollection());
-  KStdAction::quit(kapp, SLOT(quit()), actionCollection());
+  KStdAction::quit( this, SLOT( close() ), actionCollection());
   KStdAction::copy( this, SLOT( slotEditCopy() ), actionCollection() );
 
   m_toolbarAction = KStdAction::showToolbar(this,
@@ -517,7 +517,7 @@ void KitaMainWindow::setUrl(const KURL& url)
 
 void KitaMainWindow::bookmark( const Kita::Thread& thread, bool on )
 {
-  Kita::Thread* t = new Kita::Thread( thread.getBoard(), thread.datURL(), thread.name(), thread.resNum() );
+  Kita::Thread* t = new Kita::Thread( thread.datURL(), thread.name(), thread.resNum() );
   FavoriteThreads* favorite = FavoriteThreads::getInstance();
 
   if( on ) {
