@@ -18,7 +18,6 @@
 #include <kapplication.h>
 #include <kdockwidget.h>
 
-#include "kitaview.h"
 #include "kitaconfig.h"
 
 #include "libkita/thread.h"
@@ -26,9 +25,9 @@
 class KPrinter;
 class KToggleAction;
 class KURL;
-class KitaThreadView;
+class KitaThreadTabWidget;
 class KitaBoardView;
-class KitaSubjectView;
+class KitaSubjectTabWidget;
 class KLineEdit;
 
 namespace KParts{
@@ -101,12 +100,14 @@ private slots:
     void windowShowBoardlist();
     void windowShowSubjectlist();
     void windowMenuAboutToShow();
+    void slotEditCopy();
 
     void changeStatusbar(const QString& text);
     void changeCaption(const QString& text);
     void slotOpenURLRequest(const KURL& url, const KParts::URLArgs&);
     void updateThreadCache( const Kita::Thread& thread );
     void setFont( const QFont& font );
+    void setThreadFont( const QFont& font );
     void slotWriteSucceeded();
     void slotUrlLine();
     void setUrl(const KURL& url);
@@ -114,9 +115,9 @@ private slots:
     void slotThread( const Kita::Thread& thread );
 
 private:
-    KitaThreadView *m_threadView;
+    KitaThreadTabWidget* m_threadView;
     KitaBoardView* m_boardView;
-    KitaSubjectView* m_subjectView;
+    KitaSubjectTabWidget* m_subjectView;
     KLineEdit* m_urlLine;
 
     KPrinter   *m_printer;
