@@ -58,9 +58,10 @@ Kita::Board KitaBoardView::getBoard(const QString& line) const
   if( regexp.search(line) != -1 ) {
     QString board_url = regexp.cap(1);
     QString board_title = regexp.cap(2);
+    Kita::Board::setName( board_url, board_title );
     return Kita::Board(board_url, board_title);
   } else {
-    return Kita::Board(KURL());
+    return Kita::Board( "" );
   }
 }
 
@@ -118,7 +119,7 @@ void KitaBoardView::loadBoardList()
     for(QValueListIterator<Kita::Board> it = board_list.begin(); it != board_list.end(); ++it)
     {
       Kita::Board board = (*it);
-      previousBoard = new KListViewItem(categoryItem, previousBoard, board.name(), board.url().url());
+      previousBoard = new KListViewItem(categoryItem, previousBoard, board.name(), board.url());
     }
     previous = categoryItem;
   }
@@ -144,7 +145,9 @@ QPtrList<Kita::Category> KitaBoardView::getCategoryList(const QString& html) con
       Kita::Board board = getBoard(*it);
 
       if( isBoardUrl(board.url()) ) {
-        current_category->append(board);
+        if( current_category ) {
+          current_category->append(board);
+        }
       }
     }
   }
@@ -163,7 +166,7 @@ void KitaBoardView::printCateogryList(QPtrList<Kita::Category>& list)
     for(it2 = board_list.begin(); it2 != board_list.end(); ++it2) {
       kdDebug() << "category:" << category->name()
       << "name:" << (const char*)(*it2).name()
-      << "url:" << (*it2).url().url() << endl;
+      << "url:" << (*it2).url() << endl;
     }
   }
 }
@@ -171,13 +174,13 @@ void KitaBoardView::printCateogryList(QPtrList<Kita::Category>& list)
 void KitaBoardView::loadBoard( QListViewItem* item )
 {
   QString boardName = item->text(0);
-  KURL url = item->text(1);
+  QString url = item->text(1);
 
-  if(item->text(1).isEmpty()) {
+  if( url.isEmpty() ) {
     return;
   }
 
-  Kita::Board board(url, boardName);
+  Kita::Board board( url, boardName );
   emit clicked( board );
 }
 
