@@ -34,6 +34,7 @@
 #include "kitacacheinfo.h"
 #include "part/kita2ch.h"
 #include "libkita/thread.h"
+#include "libkita/kita_misc.h"
 
 enum SubjectViewRows {
   Row_Mark,
@@ -92,7 +93,8 @@ void KitaSubjectView::loadThread( int, QListViewItem* item )
   KURL datURL = m_board.url();
   datURL.addPath("/dat/" + datName);
 
-  Kita::Thread* thread = new Kita::Thread( m_board, datURL,
+  Kita::Board::setName( Kita::datToBoard( datURL.url() ), m_board.name() );
+  Kita::Thread* thread = new Kita::Thread( datURL,
                                            item->text( Row_Subject ),
                                            item->text( Row_Read ).toInt() );
 
@@ -268,7 +270,8 @@ void KitaSubjectView::slotContextMenuRequested( QListViewItem* item, const QPoin
   KURL datURL = m_board.url();
   datURL.addPath("/dat/" + datName);
 
-  Kita::Thread thread( m_board, datURL );
+  Kita::Board::setName( Kita::datToBoard( datURL.url() ), m_board.name() );
+  Kita::Thread thread( datURL );
   thread.setName( item->text( Row_Subject ) );
   thread.setResNum( item->text( Row_Read ).toInt() );
 
@@ -282,7 +285,7 @@ void KitaSubjectView::slotContextMenuRequested( QListViewItem* item, const QPoin
     emit signalShowThreadWithNewTab( thread );
     break;
   case 2:
-    clipboard->setText( thread.name() + "\n" + thread.url().url() );
+    clipboard->setText( thread.name() + "\n" + thread.url() );
     break;
   default:
     break;
