@@ -20,59 +20,41 @@
 
 #include <qwidget.h>
 #include <qapplication.h>
+#include <qregexp.h>
 
 #include "board.h"
+#include "kita_misc.h"
 #include "qcp932codec.h"
 
 using namespace Kita;
 
 ThreadFactory* ThreadFactory::instance = 0;
 
-Thread::Thread() : m_board( 0 )
+Thread::Thread()
 {
 }
 
-Thread::Thread(const Board& board, const KURL& datURL, const QString threadName, int resNum)
-  : m_datURL(datURL), m_threadName(threadName), m_resNum(resNum)
+Thread::Thread( const KURL& datURL, const QString& threadName, int resNum )
+  : m_datURL( datURL ), m_threadName( threadName ), m_resNum( resNum )
 {
-  Q_ASSERT( datURL.url().right( 3 ) == QString( "dat" ) );
-
-  m_datID = m_datURL.filename().section(".", 0, 0);
-  m_board = new Board( board.url(), board.name() );
-  m_boardID = m_board->id();
-}
-
-Thread::Thread(const Board* board, const KURL& datURL, const QString threadName, int resNum)
-  : m_datURL(datURL), m_threadName(threadName), m_resNum(resNum)
-{
-  m_datID = m_datURL.filename().section(".", 0, 0);
-  m_board = new Board( board->url(), board->name() );
-  m_boardID = m_board->id();
 }
 
 Thread::Thread( const Thread& obj )
 {
   m_datURL = obj.m_datURL;
-  m_datID = obj.m_datID;
-  m_boardID = obj.m_boardID;
   m_threadName = obj.m_threadName;
   m_resNum = obj.m_resNum;
-  m_board = new Board( obj.m_board->url(), obj.m_board->name() );
 }
 
 Thread::~Thread()
 {
-  delete m_board;
 }
 
 Thread& Thread::operator=( const Thread& obj )
 {
   m_datURL = obj.m_datURL;
-  m_datID = obj.m_datID;
-  m_boardID = obj.m_boardID;
   m_threadName = obj.m_threadName;
   m_resNum = obj.m_resNum;
-  m_board = new Board( obj.m_board->url(), obj.m_board->name() );
 
   return *this;
 }
@@ -82,18 +64,14 @@ const KURL& Thread::datURL() const
   return m_datURL;
 }
 
-const KURL Thread::url() const
+const QString Thread::url() const
 {
-  KURL url = KURL(m_datURL, "/test/read.cgi/");
-  url.addPath(m_boardID + "/");
-  url.addPath(m_datID + "/");
-
-  return url;
+    return datToThread( m_datURL.url() );
 }
 
-const QString& Thread::datID() const
+const QString Thread::datID() const
 {
-  return m_datID;
+  return m_datURL.filename().section( ".", 0, 0 );
 }
 
 int Thread::resNum() const
@@ -108,17 +86,18 @@ const QString& Thread::name() const
 
 const QString& Thread::boardName() const
 {
-  return m_board->name();
+    Board* board = Board::getByURL( boardURL() );
+    return board->name();
 }
 
-const KURL& Thread::boardUrl() const
+const QString Thread::boardURL() const
 {
-  return m_board->url();
+  return datToBoard( m_datURL.url() );
 }
 
-const QString Thread::boardId() const
+const QString Thread::boardID() const
 {
-  return m_board->id();
+  return KURL( datToBoard( m_datURL.url() ) ).fileName();
 }
 
 const QString Thread::toXmlFragment() const
@@ -129,7 +108,13 @@ const QString Thread::toXmlFragment() const
   ret += QString("<daturl>%1</daturl>\n").arg( m_datURL.url() );
   ret += QString("<name>%1</name>\n").arg( m_threadName );
   ret += QString("<resnum>%1</resnum>\n").arg( m_resNum );
-  ret += m_board->toXmlFragment();
+
+  // FIXME: Board饹饳ԡ
+  ret += "<board xmlns=\"http://kita.sourceforge.jp/ns/board\">\n";
+  ret += QString("<url>%1</url>\n").arg( boardURL() );
+  ret += QString("<name>%1</name>\n").arg( boardName() );
+  ret += "</board>\n";
+
   ret += "</thread>\n";
 
   return ret;
@@ -155,94 +140,6 @@ Thread Thread::fromXml( const QString& xml )
   return thread;
 }
 
-bool Thread::test()
-{
-  kdDebug() << "Thread::test()" << endl;
-  Thread thread = Thread::fromXml( "<thread xmlns=\"http://kita.sourceforge.jp/ns/thread\">\n"
-                                   "<daturl>http://pc.2ch.net/linux/dat/1022744633.dat</daturl>\n"
-                                   "<name>2ch browser thread</name>\n"
-                                   "<resnum>700</resnum>\n"
-                                   "<board xmlns=\"http://kita.sourceforge.jp/ns/board\">\n"
-                                   "<url>http://pc.2ch.net/linux/</url>\n"
-                                   "<name>Linux</name>\n"
-                                   "</board>\n"
-                                   "</thread>\n" );
-
-  // TODO: ǻȤƤkdErrorλϲȤ
-  if( thread.datURL().url() != "http://pc.2ch.net/linux/dat/1022744633.dat" ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-  if( thread.url().url() != "http://pc.2ch.net/test/read.cgi/linux/1022744633/" ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-  if( thread.name() != "2ch browser thread" ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-  if( thread.resNum() != 700 ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-  if( thread.getBoard()->url().url() != "http://pc.2ch.net/linux/" ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-  if( thread.getBoard()->name() != "Linux" ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-
-  Thread thread2 = Thread::fromXml( thread.toXmlFragment() );
-
-  if( thread2.datURL().url() != "http://pc.2ch.net/linux/dat/1022744633.dat" ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-  if( thread2.url().url() != "http://pc.2ch.net/test/read.cgi/linux/1022744633/" ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-  if( thread2.name() != "2ch browser thread" ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-  if( thread2.resNum() != 700 ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-  if( thread2.getBoard()->url().url() != "http://pc.2ch.net/linux/" ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-  if( thread2.getBoard()->name() != "Linux" ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-
-  kdDebug() << thread.toXmlFragment() << endl;
-
-  thread = Thread::fromXml( "<thread xmlns=\"http://kita.sourceforge.jp/ns/thread\">\n"
-                            "  <daturl>http://pc.2ch.net/linux/dat/1022744633.dat</daturl>\n"
-                            "  <name>2ch browser thread</name>\n"
-                            "  <resnum>700</resnum>\n"
-                            "  <board xmlns=\"http://kita.sourceforge.jp/ns/board\">\n"
-                            "    <url>http://pc.2ch.net/linux/</url>\n"
-                            "    <name>Linux</name>\n"
-                            "  </board>\n"
-                            "</thread>\n" );
-
-  if( thread.datURL().url() != "http://pc.2ch.net/linux/dat/1022744633.dat" ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-  if( thread.url().url() != "http://pc.2ch.net/test/read.cgi/linux/1022744633/" ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-  if( thread.name() != "2ch browser thread" ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-  if( thread.resNum() != 700 ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-  if( thread.getBoard()->url().url() != "http://pc.2ch.net/linux/" ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-  if( thread.getBoard()->name() != "Linux" ) {
-    kdError() << "inValid: line=" << __LINE__ << endl;
-  }
-
-  return true;
-}
-
 bool ThreadXmlParser::startElement( const QString& namespaceURI, const QString& localName, const QString& qName, const QXmlAttributes& atts )
 {
   if( m_inBoard ) {
@@ -288,7 +185,8 @@ bool ThreadXmlParser::endElement( const QString& namespaceURI, const QString& lo
     m_boardParser->endElement( namespaceURI, localName, qName );
   } else if( localName == "thread" ) {
     m_inThread = false;
-    m_thread = Kita::Thread( *m_board, KURL( m_datUrlStr ), m_threadName, m_resNum );
+    Kita::Board::setName( datToBoard( m_datUrlStr ), m_board->name() );
+    m_thread = Kita::Thread( KURL( m_datUrlStr ), m_threadName, m_resNum );
     m_isValid = true;
     // create thread;
   } else if( localName == "daturl" ) {
@@ -356,7 +254,8 @@ void ThreadAccess::enter_loop()
 void ThreadAccess::slotRedirection(KIO::Job *, const KURL & newURL)
 {
   kdDebug() << "Redirected to newURL: " << newURL.url() << endl;
-  m_thread = Kita::Thread( m_thread.getBoard(), newURL);
+  Kita::Board::setName( datToBoard( newURL.url() ), m_thread.boardName() );
+  m_thread = Kita::Thread( newURL);
   emit redirection( newURL.url() );
 }
 
@@ -382,13 +281,34 @@ void ThreadAccess::killJob()
   if( m_currentJob ) m_currentJob->kill();
 }
 
+int ThreadAccess::serverTime()
+{
+    // parse HTTP headers
+    QStringList headerList = QStringList::split( "\n", m_header );
+    QRegExp regexp( "Date: (...), (..) (...) (....) (..:..:..) .*" );
+    QString dateStr = headerList.grep(regexp)[0];
+    if( regexp.search(dateStr) == -1 ) {
+        // invalid date format
+        return QDateTime::currentDateTime().toTime_t();
+    } else {
+        // I hate this format ;p
+        QString usLocalDateStr = regexp.cap(1) + " " + regexp.cap(3) + " " +
+                                 regexp.cap(2) + " " + regexp.cap(5) + " " +
+                                 regexp.cap(4);
+
+        // 1970/01/01 00:00:00 GMT
+        QDateTime zeroTime(QDate(1970, 1, 1), QTime(0, 0));
+        return zeroTime.secsTo(QDateTime::fromString(usLocalDateStr));
+    }
+}
+
 void ThreadFactory::insertThread( Thread& thread )
 {
   if( ! instance ) {
     instance = new ThreadFactory();
   }
 
-  Thread* new_thread = new Thread( thread.getBoard(), thread.datURL(), thread.name(), thread.resNum() );
+  Thread* new_thread = new Thread( thread.datURL(), thread.name(), thread.resNum() );
   instance->m_dict.insert( thread.datURL().url(), new_thread );
 }
 
