@@ -15,6 +15,7 @@
 
 #include <qobject.h>
 #include <qxml.h>
+#include <qdict.h>
 
 namespace KIO {
   class Job;
@@ -31,34 +32,39 @@ namespace Kita {
   class Thread
   {
     KURL m_datURL;
-    QString m_datID;
-    QString m_boardID;
     QString m_threadName;
     int m_resNum;
-    Board* m_board;
   public:
     Thread();
     Thread( const Thread& obj );
-    Thread(const Board& board, const KURL& datURL, const QString threadName = QString::null, int resNum = 0);
-    Thread(const Board* board, const KURL& datURL, const QString threadName = QString::null, int resNum = 0);
+    Thread( const KURL& datURL, const QString& threadName = QString::null, int resNum = 0 );
     ~Thread();
     Thread& operator=( const Thread& obj );
     const KURL& datURL() const;
-    const KURL url() const;
-    const QString& datID() const;
+    const QString url() const;
+    const QString datID() const;
     int resNum() const;
     const QString& name() const;
     void setName(const QString& name) { m_threadName = name; }
     void setResNum(int resNum) { m_resNum = resNum; }
-    const Board* getBoard() const { return m_board; }
     const QString& boardName() const;
-    const KURL& boardUrl() const;
-    const QString boardId() const;
+    const QString boardURL() const;
+    const QString boardID() const;
 
     const QString toXmlFragment() const;
     static Thread fromXml( const QString& xml );
+  };
 
-    static bool test();
+  class ThreadFactory
+  {
+  public:
+    static void insertThread( Thread& thread );
+    static Thread* getThread( QString& datURL );
+  private:
+    ThreadFactory() {};
+    ~ThreadFactory() {};
+    static ThreadFactory* instance;
+    QDict<Thread> m_dict;
   };
 
   class ThreadXmlParser : public QXmlDefaultHandler
@@ -96,8 +102,8 @@ namespace Kita {
     ThreadAccess( const Thread& thread ) : m_thread(thread) {};
     ~ThreadAccess() {};
     QString get();
-    QString getHeader() const { return m_header; }
     void killJob();
+    int serverTime();
   private:
     void enter_loop();
   private slots:
