@@ -9,6 +9,9 @@
  ***************************************************************************/
 
 #include "kita.h"
+
+#include <config.h>
+
 #include <kuniqueapplication.h>
 #include <dcopclient.h>
 #include <kaboutdata.h>
@@ -18,7 +21,7 @@
 static const char *description =
     I18N_NOOP("A KDE Application");
 
-static const char *version = "0.63";
+static const char *version = VERSION;
 
 static KCmdLineOptions options[] =
 {
