@@ -19,12 +19,15 @@
 class KitaConfig{
   static KitaConfig* instance;
   QFont m_font;
+  QFont m_threadFont;
   KitaConfig();
   virtual ~KitaConfig();
 public:
   static KitaConfig* getInstance();
   static QFont& font() { return getInstance()->m_font;}
   static void setFont(QFont font) { getInstance()->m_font = font; }
+  static QFont& threadFont() { return getInstance()->m_threadFont; }
+  static void setThreadFont( QFont font ) { getInstance()->m_threadFont = font; }
 };
 
 #endif
