@@ -60,7 +60,6 @@ static const char* kokomade_yonda = "<p style=\"background-color: #CCCCCC; text-
 KitaThreadView::KitaThreadView(QWidget *parent, const char *name)
     : KitaThreadViewBase(parent, name)
     , m_access( 0 )
-    , m_parent( parent )
     , m_popup( 0 )
 {
   m_threadPart = new KitaHTMLPart(threadFrame);
@@ -145,30 +144,9 @@ void KitaThreadView::showThread( const Kita::Thread& thread )
   m_access = new Kita::ThreadAccess( thread );
   connect( m_access, SIGNAL( redirection( const QString& ) ), SIGNAL( setLocationBarURL( const QString& ) ) );
   QString result = m_access->get();
-  m_serverTime = getServerTimeFromHttpHeaders( m_access->getHeader() );
   update( result );
 }
 
-int KitaThreadView::getServerTimeFromHttpHeaders( const QString& headers )
-{
-  // parse HTTP headers
-  QStringList headerList = QStringList::split("\n", headers);
-  QRegExp regexp("Date: (...), (..) (...) (....) (..:..:..) .*");
-  QString dateStr = headerList.grep(regexp)[0];
-  if(regexp.search(dateStr) == -1) {
-    // invalid date format
-    return QDateTime::currentDateTime().toTime_t();
-  } else {
-    // I hate this format ;p
-    QString usLocalDateStr = regexp.cap(1) + " " + regexp.cap(3) + " " +
-                             regexp.cap(2) + " " + regexp.cap(5) + " " + regexp.cap(4);
-
-    // 1970/01/01 00:00:00 GMT
-    QDateTime zeroTime(QDate(1970, 1, 1), QTime(0, 0));
-    return zeroTime.secsTo(QDateTime::fromString(usLocalDateStr));
-  }
-}
-
 void KitaThreadView::setSubjectLabel(const QString& boardName, const QString& threadName)
 {
   QString disp;
@@ -193,7 +171,7 @@ void KitaThreadView::update( const QString& result )
   int divide = total / ( 100 / 5 );
   int next = divide;
   int prevResNum = m_thread.resNum();
-  QProgressDialog * progress = new QProgressDialog( m_parent );
+  QProgressDialog * progress = new QProgressDialog( parentWidget() );
   progress->setTotalSteps( static_cast<int>(total * 0.7) );
   progress->setLabelText( "Parse DAT file.....");
   progress->show();
@@ -319,14 +297,18 @@ KitaWriteDialog* KitaThreadView::openDialog( const Kita::PostInfo& info )
 void KitaThreadView::slotWriteButtonClicked()
 {
 //  QSjisCodec cp932Codec;
-  KURL bbscgiURL = KURL( m_thread.boardUrl(), "../test/bbs.cgi");
+  if( ! m_access ) {
+    kdError() << __func__ << ": m_access is null" << endl;
+    return;
+  }
+  KURL bbscgiURL = KURL( m_thread.boardURL(), "../test/bbs.cgi");
   bbscgiURL.setProtocol( "http" );
 
   Kita::PostInfo info;
   info.host = bbscgiURL.host();
-  info.bbs = m_thread.boardId();
+  info.bbs = m_thread.boardID();
   info.key = m_thread.datID();
-  info.time = QString("%1").arg(m_serverTime);
+  info.time = QString("%1").arg( m_access->serverTime() );
 
   KitaWriteDialog* dialog = openDialog( info );
   dialog->show(); // work asynchronus.
@@ -390,6 +372,10 @@ void KitaThreadView::slotOnURL(const QString& url)
 {
   emit signalChangeStatusbar(url);
 
+  if ( ! isActiveWindow() ) {
+    return;
+  }
+
   // TODO: enterEvent()ơäƤȤtipɽ뤳ȡ
   if ( ! url.isEmpty() ) {
     KHTMLView* view = m_threadPart->view();
@@ -398,12 +384,7 @@ void KitaThreadView::slotOnURL(const QString& url)
       delete m_popup;
     }
 
-    m_popup = new QFrame( view, "res_popup", WStyle_Customize | WStyle_NoBorder | WStyle_Tool | WType_TopLevel );
-    m_browser = new QTextBrowser( m_popup );
-    m_browser->zoomOut( static_cast<int>( m_browser->pointSize() * 0.3 ) );
-    m_browser->setPaletteBackgroundColor( "yellow" );
-    m_browser->setWordWrap( QTextEdit::NoWrap );
-    m_browser->setResizePolicy( QScrollView::AutoOne );
+    m_popup = new Kita::ResPopup( view );
     connect( m_threadPart->view(), SIGNAL( leave() ), SLOT( hidePopup() ) );
 
     int refNum = 0;
@@ -419,8 +400,7 @@ void KitaThreadView::slotOnURL(const QString& url)
       DOM::HTMLDListElement comment_dl = static_cast<DOM::HTMLDListElement>(comments.item( refNum - 1 ));
       QString innerHTML = comment_dl.innerHTML().string();
 
-      m_browser->setText( innerHTML );
-      m_browser->resize( m_browser->contentsWidth() + 10, m_browser->contentsHeight() );
+      m_popup->setText( innerHTML );
       m_popup->adjustSize();
 
       QPoint pos = QCursor::pos();
@@ -520,4 +500,43 @@ void KitaThreadView::killJob()
     m_access->killJob();
   }
 }
+
+namespace Kita
+{
+
+PopupTextBrowser::PopupTextBrowser( QFrame* frame )
+ : QTextBrowser( frame )
+{
+    zoomOut( static_cast<int>( pointSize() * 0.3 ) );
+    setPaletteBackgroundColor( "yellow" );
+    setWordWrap( QTextEdit::NoWrap );
+    setResizePolicy( QScrollView::AutoOne );
+}
+
+PopupTextBrowser::~ PopupTextBrowser()
+{
+}
+
+ResPopup::ResPopup( KHTMLView* view )
+  : QFrame( view, "res_popup", WStyle_Customize | WStyle_NoBorder | WStyle_Tool | WType_TopLevel | WX11BypassWM )
+{
+  m_browser = new Kita::PopupTextBrowser( this );
+}
+
+ResPopup::~ ResPopup()
+{
+}
+
+void ResPopup::setText( QString& str )
+{
+  m_browser->setText( str );
+}
+
+void ResPopup::adjustSize()
+{
+  m_browser->resize( m_browser->contentsWidth() + 10, m_browser->contentsHeight() );
+  QFrame::adjustSize();
+}
+
+};
 // vim:sw=2:
