@@ -16,19 +16,22 @@
 #include <kparts/browserextension.h>
 #include <dom/html_base.h>
 
+#include <qtextbrowser.h>
+
 #include "kita2ch.h"
 #include "libkita/thread.h"
 
 class KURL;
 class KitaHTMLPart;
 class KitaWriteDialog;
-class QTextBrowser;
 
 #include <qvaluestack.h> // for gcc-2.9x
 template<class T> class QValueStack;
 
 namespace Kita {
   class ThreadAccess;
+  class PopupTextBrowser;
+  class ResPopup;
 };
 
 namespace KIO {
@@ -65,15 +68,11 @@ private: // Private attributes
   Kita::ThreadAccess* m_access;
   Kita::Thread m_thread;
   KitaHTMLPart* m_threadPart;
-  int m_serverTime;
-  QWidget * m_parent;
   Kita::PostInfo m_postInfo;
-  QFrame* m_popup;
-  QTextBrowser* m_browser;
+  Kita::ResPopup* m_popup;
 
   void insertSearchCombo();
   KURL filterReadCGI( const KURL& );
-  int getServerTimeFromHttpHeaders( const QString& headers );
   void setSubjectLabel( const QString& boardName, const QString& threadName );
   KitaWriteDialog* openDialog( const Kita::PostInfo& info );
   const QString footer( int ) const;
@@ -108,4 +107,23 @@ signals:
   void bookmarked( const Kita::Thread&, bool on );
 };
 
+namespace Kita {
+  class PopupTextBrowser : public QTextBrowser
+  {
+  public:
+    PopupTextBrowser( QFrame* frame );
+    ~PopupTextBrowser();
+  };
+
+  class ResPopup : public QFrame
+  {
+    Kita::PopupTextBrowser* m_browser;
+  public:
+    ResPopup( KHTMLView* view );
+    ~ResPopup();
+    void setText( QString& str );
+    void adjustSize();
+  };
+}
+
 #endif
